Loading...
src/ImageLoader.cpp dyld-95.3 dyld-97.1
--- dyld/dyld-95.3/src/ImageLoader.cpp
+++ dyld/dyld-97.1/src/ImageLoader.cpp
@@ -91,6 +91,7 @@
 #endif
 	fAllLazyPointersBound = false;
 	fBeingRemoved = false;
+	fAddFuncNotified = false;
 	fPathOwnedByImage = false;
 #if RECURSIVE_INITIALIZER_LOCK
 	fInitializerRecursiveLock = NULL;
@@ -472,8 +473,8 @@
 					libInfo.image->bindAllLazyPointers(context, recursive);
 			}
 		}
-		// bind lazys in this image
-		this->doBind(context, true);
+		// bind lazies in this image
+		this->doBindJustLazies(context);
 	}
 }